==> zio-aws-kendra_2.13-5.17.151.1-sources.jar: zio/aws/kendra/model/BatchDeleteDocumentResponse.scala <==
package zio.aws.kendra.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class BatchDeleteDocumentResponse(
    failedDocuments: Option[
      Iterable[zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse = {
    import BatchDeleteDocumentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
      .builder()
      .optionallyWith(
        failedDocuments.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedDocuments)
      .build()
  }
  def asReadOnly: zio.aws.kendra.model.BatchDeleteDocumentResponse.ReadOnly =
    zio.aws.kendra.model.BatchDeleteDocumentResponse.wrap(buildAwsValue())
}
object BatchDeleteDocumentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kendra.model.BatchDeleteDocumentResponse =
      zio.aws.kendra.model.BatchDeleteDocumentResponse(
        failedDocuments.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def failedDocuments: Option[List[
      zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument.ReadOnly
    ]]
    def getFailedDocuments: ZIO[Any, AwsError, List[
      zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument.ReadOnly
    ]] = AwsError.unwrapOptionField("failedDocuments", failedDocuments)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
  ) extends zio.aws.kendra.model.BatchDeleteDocumentResponse.ReadOnly {
    override val failedDocuments: Option[List[
      zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument.ReadOnly
    ]] = scala
      .Option(impl.failedDocuments())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
  ): zio.aws.kendra.model.BatchDeleteDocumentResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-kendra_2.13-5.19.8.4-sources.jar: zio/aws/kendra/model/BatchDeleteDocumentResponse.scala <==
package zio.aws.kendra.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BatchDeleteDocumentResponse(
    failedDocuments: Optional[
      Iterable[zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse = {
    import BatchDeleteDocumentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
      .builder()
      .optionallyWith(
        failedDocuments.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.failedDocuments)
      .build()
  }
  def asReadOnly: zio.aws.kendra.model.BatchDeleteDocumentResponse.ReadOnly =
    zio.aws.kendra.model.BatchDeleteDocumentResponse.wrap(buildAwsValue())
}
object BatchDeleteDocumentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kendra.model.BatchDeleteDocumentResponse =
      zio.aws.kendra.model.BatchDeleteDocumentResponse(
        failedDocuments.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def failedDocuments: Optional[List[
      zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument.ReadOnly
    ]]
    def getFailedDocuments: ZIO[Any, AwsError, List[
      zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument.ReadOnly
    ]] = AwsError.unwrapOptionField("failedDocuments", failedDocuments)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
  ) extends zio.aws.kendra.model.BatchDeleteDocumentResponse.ReadOnly {
    override val failedDocuments: Optional[List[
      zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.failedDocuments())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kendra.model.BatchDeleteDocumentResponseFailedDocument
            .wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kendra.model.BatchDeleteDocumentResponse
  ): zio.aws.kendra.model.BatchDeleteDocumentResponse.ReadOnly = new Wrapper(
    impl
  )
}
